
/*
Copyright (C) 2004 Douglas Thain
This work is made available under a BSD-style license.
See the file COPYING for details.
*/

#ifndef CHIRP_CLIENT_H
#define CHIRP_CLIENT_H

#include <fcntl.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/statfs.h>
#include <stdio.h>
#include <time.h>

typedef void (*chirp_dir_t) ( const char *path, void *arg );

struct chirp_client * chirp_client_connect_condor( time_t stoptime );
struct chirp_client * chirp_client_connect( const char *host, int negotiate_auth, time_t stoptime );

void chirp_client_disconnect( struct chirp_client *c );
int  chirp_client_serial( struct chirp_client *c );

int chirp_client_open( struct chirp_client *c, const char *path, int flags, int mode, struct stat *buf, time_t stoptime );
int chirp_client_close( struct chirp_client *c, int fd, time_t stoptime );
int chirp_client_pread( struct chirp_client *c, int fd, void *buffer, int length, int offset, time_t stoptime );
int chirp_client_pwrite( struct chirp_client *c, int fd, const void *buffer, int length, int offset, time_t stoptime );
int chirp_client_fsync( struct chirp_client *c, int fd, time_t stoptime );
int chirp_client_fstat( struct chirp_client *c, int fd, struct stat *buf, time_t stoptime );
int chirp_client_fstatfs( struct chirp_client *c, int fd, struct statfs *buf, time_t stoptime );
int chirp_client_fchown( struct chirp_client *c, int fd, uid_t uid, gid_t gid, time_t stoptime );
int chirp_client_fchmod( struct chirp_client *c, int fd, int mode, time_t stoptime );
int chirp_client_ftruncate( struct chirp_client *c, int fd, int length, time_t stoptime );


int chirp_client_getfile( struct chirp_client *c, const char *name, FILE *stream, time_t stoptime );
int chirp_client_putfile( struct chirp_client *c, const char *name, FILE *stream, int mode, int length, time_t stoptime );
int chirp_client_cookie( struct chirp_client *c, const char *cookie, time_t stoptime );
int chirp_client_lookup( struct chirp_client *c, const char *logical_name, char **url, time_t stoptime );
int chirp_client_getdir( struct chirp_client *c, const char *path, chirp_dir_t callback, void *arg, time_t stoptime );

int chirp_client_unlink( struct chirp_client *c, const char *path, time_t stoptime );
int chirp_client_rename( struct chirp_client *c, const char *path, const char *newpath, time_t stoptime );
int chirp_client_link( struct chirp_client *c, const char *path, const char *newpath, time_t stoptime );
int chirp_client_symlink( struct chirp_client *c, const char *path, const char *newpath, time_t stoptime );
int chirp_client_readlink( struct chirp_client *c, const char *path, char *buf, int length, time_t stoptime );
int chirp_client_mkdir( struct chirp_client *c, char const *path, int mode, time_t stoptime );
int chirp_client_rmdir( struct chirp_client *c, char const *path, time_t stoptime );
int chirp_client_stat( struct chirp_client *c, const char *path, struct stat *buf, time_t stoptime );
int chirp_client_lstat( struct chirp_client *c, const char *path, struct stat *buf, time_t stoptime );
int chirp_client_statfs( struct chirp_client *c, const char *path, struct statfs *buf, time_t stoptime );
int chirp_client_access( struct chirp_client *c, const char *path, int mode, time_t stoptime );
int chirp_client_chmod( struct chirp_client *c, const char *path, int mode, time_t stoptime );
int chirp_client_chown( struct chirp_client *c, const char *path, uid_t uid, gid_t gid, time_t stoptime );
int chirp_client_lchown( struct chirp_client *c, const char *path, uid_t uid, gid_t gid, time_t stoptime );
int chirp_client_truncate( struct chirp_client *c, const char *path, int length, time_t stoptime );
int chirp_client_utime( struct chirp_client *c, const char *path, time_t actime, time_t modtime, time_t stoptime );
int chirp_client_canonicalize( struct chirp_client *c, const char *path, char *newpath, int length, time_t stoptime );

#endif

