/*
Copyright (C) 2004 Douglas Thain
This work is made available under a BSD-style license.
See the file COPYING for details.
*/

#ifndef CHIRP_RELI_H
#define CHIRP_RELI_H

#include "chirp_client.h"

#include <sys/types.h>
#include <stdio.h>

struct chirp_file * chirp_reli_open( const char *host, const char *path, int flags, int mode, time_t stoptime );
int chirp_reli_close( struct chirp_file *file, time_t stoptime );
int chirp_reli_pread( struct chirp_file *file, void *buffer, int length, int offset, time_t stoptime );
int chirp_reli_pwrite( struct chirp_file *file, const void *buffer, int length, int offset, time_t stoptime );
int chirp_reli_fstat( struct chirp_file *file, struct stat *buf, time_t stoptime );
int chirp_reli_fstatfs( struct chirp_file *file, struct statfs *buf, time_t stoptime );
int chirp_reli_fchown( struct chirp_file *file, uid_t uid, gid_t gid, time_t stoptime );
int chirp_reli_fchmod( struct chirp_file *file, int mode, time_t stoptime );
int chirp_reli_ftruncate( struct chirp_file *file, int length, time_t stoptime );

int chirp_reli_lookup( const char *host, const char *path, char **redirect, time_t stoptime );
int chirp_reli_getfile( const char *host, const char *path, FILE *stream, time_t stoptime );
int chirp_reli_putfile( const char *host, const char *path, FILE *stream, int mode, int length, time_t stoptime );
int chirp_reli_getdir( const char *host, const char *path, chirp_dir_t callback, void *arg, time_t stoptime );
int chirp_reli_unlink( const char *host, const char *path, time_t stoptime );
int chirp_reli_rename( const char *host, const char *path, const char *newpath, time_t stoptime );
int chirp_reli_link( const char *host, const char *path, const char *newpath, time_t stoptime );
int chirp_reli_symlink( const char *host, const char *path, const char *newpath, time_t stoptime );
int chirp_reli_readlink( const char *host, const char *path, char *buf, int length, time_t stoptime );
int chirp_reli_mkdir( const char *host, char const *path, int mode, time_t stoptime );
int chirp_reli_rmdir( const char *host, char const *path, time_t stoptime );
int chirp_reli_stat( const char *host, const char *path, struct stat *buf, time_t stoptime );
int chirp_reli_lstat( const char *host, const char *path, struct stat *buf, time_t stoptime );
int chirp_reli_statfs( const char *host, const char *path, struct statfs *buf, time_t stoptime );
int chirp_reli_access( const char *host, const char *path, int mode, time_t stoptime );
int chirp_reli_chmod( const char *host, const char *path, int mode, time_t stoptime );
int chirp_reli_chown( const char *host, const char *path, uid_t uid, gid_t gid, time_t stoptime );
int chirp_reli_lchown( const char *host, const char *path, uid_t uid, gid_t gid, time_t stoptime );
int chirp_reli_truncate( const char *host, const char *path, int length, time_t stoptime );
int chirp_reli_utime( const char *host, const char *path, time_t actime, time_t modtime, time_t stoptime );
int chirp_reli_canonicalize( const char *host, const char *path, char *newpath, int length, time_t stoptime );

#endif
